/**
 * @license Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or http://ckeditor.com/license
 */

CKEDITOR.plugins.setLang( 'codesnippet', 'fi', {
	button: 'Lisää koodileike',
	codeContents: 'Koodisisältö',
	emptySnippetError: 'Koodileike ei voi olla tyhjä.',
	language: 'Kieli',
	title: 'Koodileike',
	pathName: 'koodileike'
} );
